@@ -38,11 +38,15 @@ activityOverlap <- function(recordTable,
 
   subset_speciesA <- subset(recordTable, recordTable[,speciesCol] == speciesA)
   subset_speciesB <- subset(recordTable, recordTable[,speciesCol] == speciesB)
+  
+  if(nrow(subset_speciesA) == 1) stop("speciesA has only 1 record. Cannot estimate density.")
+  if(nrow(subset_speciesB) == 1) stop("speciesB has only 1 record. Cannot estimate density.")
 
   if(any(is.na( c(subset_speciesA$Time.rad, subset_speciesB$Time.rad))))stop("NAs produced in converting to radial time. Sorry, that's a bug. Please report it.")
 
   n_record_string <- paste("number of records:", paste(nrow(subset_speciesA), nrow(subset_speciesB), sep = " / "))
   
+   
   # set graphics  parameters and out directory
   overlapEst.tmp <- overlap::overlapEst(A = subset_speciesA$Time.rad, B = subset_speciesB$Time.rad)
 
