@@ -25,7 +25,7 @@ imageRename <- function(inDir,
     keepCameraSubfolders <- FALSE
    }
    if(hasArg(hasCameraFolders) & hasArg(keepCameraSubfolders)){
-    if(keepCameraSubfolders == TRUE & hasCameraFolders == FALSE){stop("If hasCameraFolders is FALSE, keepCameraSubfolders must be FALSE too")}
+    if(keepCameraSubfolders == TRUE & hasCameraFolders == FALSE){stop("If hasCameraFolders is FALSE, keepCameraSubfolders must be FALSE too", call. = FALSE)}
    }
   
   
@@ -33,20 +33,20 @@ imageRename <- function(inDir,
   if(hasArg(outDir)){
     stopifnot(length(outDir) == 1)
     if(isTRUE(all(unlist(strsplit(tolower(inDir), split = file.sep)) %in%
-                  unlist(strsplit(tolower(outDir), split = file.sep))))) stop("outDir may not be identical to or a subdirectory of inDir")
+                  unlist(strsplit(tolower(outDir), split = file.sep))))) stop("outDir may not be identical to or a subdirectory of inDir", call. = FALSE)
 
     list.files.tmp <- list.files(outDir, recursive = TRUE)
-    if(copyImages == TRUE & length(list.files.tmp) >= 1) stop("outDir must be empty if you wish to copy images")
+    if(copyImages == TRUE & length(list.files.tmp) >= 1) stop("outDir must be empty if you wish to copy images", call. = FALSE)
   }
   if(copyImages == TRUE){
     
-    if(any(c(grep("/$", inDir) == 1, grep("/$", outDir) == 1))) stop("inDir and outDir may not end with /")
+    if(any(c(grep("/$", inDir) == 1, grep("/$", outDir) == 1))) stop("inDir and outDir may not end with /", call. = FALSE)
 
   } else {
-    if(isTRUE(grepl("/$", inDir))) stop("inDir may not end with /")
+    if(isTRUE(grepl("/$", inDir))) stop("inDir may not end with /", call. = FALSE)
   }
-  if(Sys.which("exiftool") == "") stop("cannot find ExifTool")
-  if(isTRUE(writecsv) & hasArg(outDir) == FALSE) stop("writecsv is TRUE. Please specify outDir")
+  if(Sys.which("exiftool") == "") stop("cannot find ExifTool", call. = FALSE)
+  if(isTRUE(writecsv) & hasArg(outDir) == FALSE) stop("writecsv is TRUE. Please specify outDir", call. = FALSE)
 
 
 
@@ -59,7 +59,7 @@ imageRename <- function(inDir,
   list_n_files <- lapply(dirs, list.files, pattern = ".jpg$|.JPG$", recursive = TRUE)
 
   if(any(unlist(lapply(list_n_files, length)) == 0)){
-    warning("at least one station directory contains no JPEGs:  ", paste(names(which(lapply(list_n_files, length) == 0)), collapse = "; "), call. = FALSE)
+    warning("at least one station directory contains no JPEGs:  ", paste(names(which(lapply(list_n_files, length) == 0)), collapse = "; "), call. = FALSE, immediate. = TRUE)
   }
 
 
@@ -71,21 +71,15 @@ imageRename <- function(inDir,
 
     # check if there are any images not in camera trap subfolders
     if(hasCameraFolders == TRUE && length(list.files(dirs[i], pattern = ".jpg$|.JPG$", recursive = FALSE)) >= 1){
-      stop(paste("Directory ", dirs[i], " contains images not sorted into Camera Trap subfolders. Check argument 'hasCameraFolders'"))
+      stop(paste("Directory ", dirs[i], " contains images not sorted into Camera Trap subfolders. Check argument 'hasCameraFolders'"), call. = FALSE)
     }
 
-    # run exiftool to get image date and time
-
-    command.tmp <- paste('exiftool -q -f -t -r -Directory -FileName -EXIF:DateTimeOriginal -ext JPG "', dirs[i], '"', sep = "")
-    tmp1 <-  strsplit(system(command.tmp, intern=TRUE), split = "\t")
+    command.tmp  <- paste('exiftool -q -f -t -r -Directory -FileName -EXIF:DateTimeOriginal -ext JPG "', dirs[i], '"', sep = "")
     colnames.tmp <- c("Directory", "FileName", "DateTimeOriginal")
-    metadata.tmp <- as.data.frame(matrix(unlist(lapply(tmp1, FUN = function(X){X[2]})),
-                                         ncol = length(colnames.tmp),
-                                         byrow = TRUE),
-                                  stringsAsFactors = FALSE)
+    
+    # run exiftool to get image date and time
+    metadata.tmp <- runExiftool(command.tmp = command.tmp, colnames.tmp = colnames.tmp)
 
-    colnames(metadata.tmp) <- colnames.tmp
-    rm(colnames.tmp, tmp1)
 
     if(length(metadata.tmp) == 0){
       length.tmp <- length(list.files(dirs[i], pattern = ".jpg$|JPG$", ignore.case = TRUE, recursive = TRUE))
@@ -184,29 +178,22 @@ imageRename <- function(inDir,
                                             ".JPG", sep = "")
       }
 
-      # copy images
-      if(isTRUE(copyImages)){
-        if(keepCameraSubfolders == TRUE){
-          wd_out_tmp <- file.path(outDir, dirs_short[i], unique(metadata.tmp2[,cameraCol]))
-        } else {
-          wd_out_tmp <- file.path(outDir, dirs_short[i])
-        }
-        sapply(wd_out_tmp, dir.create, recursive = TRUE)
-        metadata.tmp2$CopyStatus[metadata.tmp2$DateReadable == TRUE] <- file.copy(from = apply(metadata.tmp2[metadata.tmp2$DateReadable == TRUE, c("Directory", "FileName")], MARGIN = 1, FUN = paste, collapse = file.sep),
-                                                                               to = apply(metadata.tmp2[metadata.tmp2$DateReadable == TRUE, c("outDir", "filename_new")], MARGIN = 1, FUN = paste, collapse = file.sep),
-                                                                               overwrite = FALSE)
-        metadata.tmp2$CopyStatus[metadata.tmp2$DateReadable == FALSE] <- FALSE
-        rm(wd_out_tmp)
-
-
-      } else {
-        metadata.tmp2$CopyStatus <- FALSE
-      }
       copy.info.table <- rbind(copy.info.table, metadata.tmp2)
       rm(metadata.tmp2)
     }
   }
 
+      # copy images
+      if(isTRUE(copyImages)){
+        sapply(unique(copy.info.table$outDir), dir.create, recursive = TRUE)
+        copy.info.table$CopyStatus[copy.info.table$DateReadable == TRUE] <- file.copy(from      = apply(copy.info.table[copy.info.table$DateReadable == TRUE, c("Directory", "FileName")],  MARGIN = 1, FUN = paste, collapse = file.sep),
+                                                                                      to        = apply(copy.info.table[copy.info.table$DateReadable == TRUE, c("outDir", "filename_new")], MARGIN = 1, FUN = paste, collapse = file.sep),
+                                                                                      overwrite = FALSE)
+        copy.info.table$CopyStatus[copy.info.table$DateReadable == FALSE] <- FALSE
+      } else {
+        copy.info.table$CopyStatus <- FALSE
+      }
+
   rownames(copy.info.table) <- NULL
   copy.info.table <- copy.info.table[,-which(names(copy.info.table) %in%
                                                c("DateTimeOriginal2", "DateTime_for_filename", "minute.append"))]
